@@ -1,7 +1,6 @@
 import datetime
 
-from src.finance_calculator.calculators import api as fc
-
+from finance_calculator import api as fc
 
 cashflow_data = [
     (datetime.date(2020, 3, 1), 10000),
@@ -20,5 +19,5 @@ cashflow_data = [
 
 
 def test_xirr_crude():
-    x = fc.get_xirr(cashflow_data)
-    assert x is not None
+    xirr = fc.get_xirr(cashflow_data)
+    assert type(xirr) is float
